<h1> ABUU - <u>A</u>nother <u>B</u>unch of <u>U</u>se<s>less</s>full <u>U</u>tils</h1>

Just a collection of utils I've used time and again in different python projects put together.

Main aim of this repo and package is to allow me to use it across multiple projects without having to copy paste code.
